pub struct FileUploadable {
pub name: String,
pub mimetype: String,
pub s3key: String,
}Expand description
File that can be uploaded to S3
Fields
name: StringFilename
mimetype: StringMIME type
s3key: StringS3 key after upload
Implementations
Sourceimpl FileUploadable
impl FileUploadable
Sourcepub async fn from_path(
client: &ComposioClient,
file: &Path,
tool: &str,
toolkit: &str,
) -> Result<Self, ComposioError>
pub async fn from_path( client: &ComposioClient, file: &Path, tool: &str, toolkit: &str, ) -> Result<Self, ComposioError>
Create a FileUploadable from a local file path or public URL
If the file parameter is a URL (starts with http:// or https://), it will fetch the file content from the URL and upload it to S3. Otherwise, it treats it as a local file path.
Arguments
client- The HTTP client for API callsfile- Local file path or public URLtool- The tool slugtoolkit- The toolkit slug
Returns
FileUploadable instance with S3 key
Errors
Returns error if file doesn’t exist, is not readable, or upload fails
Sourcepub async fn from_url(
client: &ComposioClient,
url: &str,
tool: &str,
toolkit: &str,
) -> Result<Self, ComposioError>
pub async fn from_url( client: &ComposioClient, url: &str, tool: &str, toolkit: &str, ) -> Result<Self, ComposioError>
Create a FileUploadable from a public URL