Module modifiers

Module modifiers 

Tool modifiers for customizing tool behavior

This module provides functionality to modify tool schemas, execution parameters, and execution responses. Modifiers allow you to customize tool behavior without changing the underlying tool definitions.

Modifier Types

Examples

use composio_sdk::models::modifiers::{Modifier, ModifierType};
use std::collections::HashMap;

// Create a before_execute modifier
let modifier = Modifier::new(
    ModifierType::BeforeExecute,
    vec!["GITHUB_CREATE_ISSUE".to_string()],
    vec![],
);

Structs

CustomAuthParams
Custom authentication parameters
CustomConnectionData
Custom connection data for various auth schemes
Modifier
A modifier that can be applied to tools
ToolExecuteParams
Parameters for tool execution

Enums

ModifierType
Type of modifier

Traits

AfterExecute
Trait for after execute modifiers
AfterExecuteMeta
Trait for after execute meta modifiers (session context)
BeforeExecute
Trait for before execute modifiers
BeforeExecuteMeta
Trait for before execute meta modifiers (session context)
SchemaModifier
Trait for schema modifiers

Functions

apply_after_execute_meta_modifiers
Apply modifiers to meta tool response
apply_after_execute_modifiers
Apply modifiers to tool execution response
apply_before_execute_meta_modifiers
Apply modifiers to meta tool parameters
apply_before_execute_modifiers
Apply modifiers to tool execution parameters
apply_schema_modifiers
Apply modifiers to tool schema

Type Aliases

Modifiers
Collection of modifiers