Modifier

Struct Modifier 

pub struct Modifier {
    pub modifier_type: ModifierType,
    pub tools: Vec<String>,
    pub toolkits: Vec<String>,
    /* private fields */
}
A modifier that can be applied to tools

Fields

modifier_type: ModifierType

Type of modifier

tools: Vec<String>

List of tool slugs this modifier applies to (empty = all tools)

toolkits: Vec<String>

List of toolkit slugs this modifier applies to (empty = all toolkits)

Implementations

Source

impl Modifier

pub fn before_execute<F>( tools: Vec<String>, toolkits: Vec<String>, modifier: F, ) -> Self
where F: BeforeExecute + 'static,

Create a new before_execute modifier

pub fn after_execute<F>( tools: Vec<String>, toolkits: Vec<String>, modifier: F, ) -> Self
where F: AfterExecute + 'static,

Create a new after_execute modifier

pub fn schema<F>(tools: Vec<String>, toolkits: Vec<String>, modifier: F) -> Self
where F: SchemaModifier + 'static,

Create a new schema modifier

pub fn before_execute_meta<F>( tools: Vec<String>, toolkits: Vec<String>, modifier: F, ) -> Self
where F: BeforeExecuteMeta + 'static,

Create a new before_execute_meta modifier

pub fn after_execute_meta<F>( tools: Vec<String>, toolkits: Vec<String>, modifier: F, ) -> Self
where F: AfterExecuteMeta + 'static,

Create a new after_execute_meta modifier

pub fn apply_to_params( &self, tool: &str, toolkit: &str, params: ToolExecuteParams, ) -> Result<ToolExecuteParams, String>

Apply the modifier to tool execution parameters

pub fn apply_to_response( &self, tool: &str, toolkit: &str, response: ToolExecutionResponse, ) -> Result<ToolExecutionResponse, String>

Apply the modifier to tool execution response

pub fn apply_to_schema( &self, tool: &str, toolkit: &str, schema: ToolSchema, ) -> Result<ToolSchema, String>

Apply the modifier to tool schema

pub fn apply_to_meta_params( &self, tool: &str, toolkit: &str, session_id: &str, params: HashMap<String, Value>, ) -> Result<HashMap<String, Value>, String>

Apply the modifier to meta tool parameters

pub fn apply_to_meta_response( &self, tool: &str, toolkit: &str, session_id: &str, response: ToolExecutionResponse, ) -> Result<ToolExecutionResponse, String>

Apply the modifier to meta tool response